---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''
---

### Description of the bug

Describe the bug here.
Try to give a minimal working example in a fresh environment.

### Description of your environment

Please give the versions of all packages installed in your fresh environment, e.g. with `pip list`.

